flup
====

This is a fork of Allan Saddi's flup package, it is intended to support both Python2
and Python3 from single code-base.

Status
======

Currently package installs on Python 3, but doesn't work correctly.


License
=======

BSD
